# raspi_components

## A python package for using certain components on the raspberry pi.

**These components include:**
- Buttons
- LEDs
- RGB LEDs
- Active Buzzers
- PCF8591
- Potentiometers
- Photoresistors
- Thermistors
- Joysticks

You can download the stable release of this package by running
`pip install raspi-components`

You can view the documentation [here](https://raspi-components.readthedocs.io/en/latest/?#).

You can visit the source code [here](https://github.com/builderdev212/raspi_components).  
You can visit the stable package on PyPI [here](https://pypi.org/project/raspi-components).
This code is based off of [Freenove's RFID Starter Kit for Raspberry Pi](https://github.com/Freenove/Freenove_RFID_Starter_Kit_for_Raspberry_Pi/)
